@@ -29,7 +29,7 @@
 #include <qtest_akonadi.h>
 
 #include <QTestEventLoop>
-#include <QtCore/QObject>
+#include <QObject>
 
 static const char *s_ourEmail = "unittests@dev.nul"; // change also in kdepimlibs/akonadi/calendar/tests/unittestenv/kdehome/share/config
 
@@ -46,7 +46,7 @@ public:
     {
     }
 
-    void start() Q_DECL_OVERRIDE
+    void start() override
     {
         UnitTestResult unitTestResult;
         unitTestResult.message     = message();
@@ -76,7 +76,7 @@ public:
     {
     }
 
-    MailTransport::MessageQueueJob *createMessageQueueJob(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = nullptr) Q_DECL_OVERRIDE
+    MailTransport::MessageQueueJob *createMessageQueueJob(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = nullptr) override
     {
         Q_UNUSED(incidence);
         Q_UNUSED(identity);
@@ -434,9 +434,6 @@ private Q_SLOTS:
         }
     }
 
-public Q_SLOTS:
-private:
-
 };
 
 QTEST_AKONADIMAIN(MailClientTest)
